@@ -48,6 +48,11 @@ if [ "$DRIVER" = "ati" -o "$DRIVER" = "atimisc" -o "$DRIVER" = "r128" -o \
     SEDLINE="s/(II) RADEON([^)]*): Panel [Ss]ize .*from [^:]*: \(.*\)/\1/;"
     getres
   fi
+  if [ -z "$RES" ]; then
+    EGREPLINE="\(WW\) RADEON\(.*\): Panel size .*x.* is derived, this may not be correct."
+    SEDLINE="s/(WW) RADEON([^)]*): Panel size \([^x]*\)x\([^ ]*\) is derived, this may not be correct./\1x\2/;"
+    getres
+  fi
   if [ -z "$RES" ]; then
     EGREPLINE="\(II\) R128\(.*\): Panel size: .*x.*"
     SEDLINE="s/(II) R128([^)]*): Panel size: \(.*\)/\1/;"
@@ -63,7 +68,7 @@ elif [ "$DRIVER" = "savage" ]; then
   getres
 elif [ "$DRIVER" = "neomagic" ]; then
   EGREPLINE="\(--\) NEOMAGIC\(.*\): Panel is a .*x.* .* .* display"
-  SEDLINE="s/(--) NEOMAGIC(.*): Panel is a \([^x]*\)x\([^ ]*\) [^ ]* [^ ]* display/\1x\2/;"
+  SEDLINE="s/(--) NEOMAGIC(.*): Panel is a \([^x]*\)x\([^ ]*\) [^ ]* .* display/\1x\2/;"
   getres
 elif [ "$DRIVER" = "nv" ]; then
   # the nv driver would ideally tell us this
@@ -98,6 +103,10 @@ elif [ "$DRIVER" = "via" ]; then
     SEDLINE="s/(II) VIA([^)]*): Selected Panel Size is \([^x]*\)x\([^ ]*\)/\1x\2/;"
     getres
   fi
+elif [ "$DRIVER" = "chips" ]; then
+  EGREPLINE="\(--\) CHIPS\(.*\): Display Size: x=.*; y=.*"
+  SEDLINE="s/(--) CHIPS([^)]*): Display Size: x=\([^;]*\); y=\([^ ]*\)/\1x\2/;"
+  getres
 else
   exit 1
 fi
